[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- pilot.coordination.advert_adaptor.AdvertCoordinationAdaptor: BigData persists its data in a central data space, e.g.
- pilot.coordination.nocoord_adaptor.NoCoordinationAdaptor: Dummy Adaptor - No distributed coordination done
- pilot.coordination.redis_adaptor.RedisCoordinationAdaptor: Dummy Adaptor - No distributed coordination done
- pilot.scheduler.data_compute_affinity_scheduler.Scheduler
- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - pilot.api.api.PilotError
  - pilot.filemanagement.bliss_adaptor.BlissFileAdaptor: BigData File Management for Pilot Data
  - pilot.api.compute.api.Callback: Callback class.
  - pilot.api.compute.api.ComputeUnit: ComputeUnit (CU).
    - pilot.impl.pilotcompute_manager.ComputeUnit: ComputeUnit (CU).
  - pilot.impl.pilot_manager.ComputeUnitService
  - pilot.api.compute.api.ComputeUnitService: ComputeUnitService (CUS).
    - pilot.api.api.ComputeDataService: ComputeDataService (CDS).
      - pilot.impl.pilot_manager.ComputeDataService: ComputeDataService (CDS).
      - pilot.impl.pilot_manager_decentral.ComputeDataServiceDecentral: ComputeDataServiceDecentral.
  - pilot.api.data.api.DataUnit: DataUnit (DU).
    - pilot.impl.pilotdata_manager.DataUnit: DataUnit (DU).
  - pilot.impl.pilotdata_manager.DataUnitItem: DataUnitItem
  - pilot.api.data.api.DataUnitService: DataUnitService (DUS).
  - pilot.impl.pilot_manager.DataUnitService
  - pilot.filemanagement.gs_adaptor.GSFileAdaptor: BigData File Management for Pilot Data
  - pilot.filemanagement.globusonline_adaptor.GlobusOnlineFileAdaptor: BigData Coordination File Management for Pilot Data
  - pilot.api.compute.api.PilotCompute: PilotCompute (PC).
    - pilot.impl.pilotcompute_manager.PilotCompute: Pilot Compute (PC).
  - pilot.api.compute.api.PilotComputeService: PilotComputeService (PCS).
    - pilot.impl.pilotcompute_manager.PilotComputeService: PilotComputeService (PCS).
  - pilot.api.data.api.PilotData: PilotData (PD).
    - pilot.impl.pilotdata_manager.PilotData: PilotData (PD).
  - pilot.api.data.api.PilotDataService: PilotDataService (PDS).
    - pilot.api.api.ComputeDataService: ComputeDataService (CDS).
      - pilot.impl.pilot_manager.ComputeDataService: ComputeDataService (CDS).
      - pilot.impl.pilot_manager_decentral.ComputeDataServiceDecentral: ComputeDataServiceDecentral.
    - pilot.impl.pilotdata_manager.PilotDataService: PilotDataService (PDS).
  - pilot.filemanagement.s3_adaptor.S3FileAdaptor: BigData File Management for Pilot Data Supports pilot data on top of S3 and Eucalyptus Walrus
  - pilot.filemanagement.ssh_adaptor.SSHFileAdaptor: BigData Coordination File Management for Pilot Store
  - pilot.api.compute.api.State: State.
  - pilot.filemanagement.webhdfs_adaptor.WebHDFSFileAdaptor
  - dict: dict() -> new empty dictionary dict(mapping) -> new dictionary initialized from a mapping object's (key, value) pairs dict(iterable) -> new dictionary initialized as if via: d = {} for k, v in iterable: d[k] = v dict(**kwargs) -> new dictionary initialized with the name=value pairs in the keyword argument list.
    - pilot.api.compute.api.ComputeUnitDescription: ComputeUnitDescription (CUD).
    - pilot.api.data.api.DataUnitDescription: DataUnitDescription (DUD).
    - pilot.api.compute.api.PilotComputeDescription: PilotComputeDescription (PCD).
    - pilot.api.data.api.PilotDataDescription: PilotDataDescription (PDD).
  - pilot.filemanagement.irods_adaptor.iRodsFileAdaptor: BigData File Management for Pilot Data Supports pilot data on top of iRods.